@@ -261,7 +261,7 @@ class Deploy(object):
     def choose_instance_type(self):
         # TO DO : add heuristic for auto selection of instance size
         
-        if self.path =='':
+        if self.prefix =='':
             tmppath = "ezsmdeploy/model-" + self.name + "/"
         else:
             tmppath = self.prefix+"/ezsmdeploy/model-" + self.name + "/"
@@ -400,7 +400,7 @@ class Deploy(object):
         if self.prefix == '':
             tmppath = "ezsmdeploy/model-"
         else:
-            tmppath = self.path + "/ezsmdeploy/model-"
+            tmppath = self.prefix + "/ezsmdeploy/model-"
         self.modelpath = []
         for name in self.model:
             self.modelpath.append(
